/*
 * @Author: zengzhe
 * @Date: 2024-12-27 11:48:34
 * @LastEditors: zengzhe
 * @LastEditTime: 2024-12-27 14:43:43
 * @Description:
 */
import { resolve } from 'path'
import { defineConfig, loadEnv } from '@rsbuild/core'
import { createPlugins } from './build/rsbuild-plugins'
import pkg from './package.json'
const { dependencies, devDependencies, name, version } = pkg
import dayjs from 'dayjs'
import AutoImport from 'unplugin-auto-import/rspack'
import Components from 'unplugin-vue-components/rspack'
import { TDesignResolver } from 'unplugin-vue-components/resolvers'
const { publicVars } = loadEnv({ prefixes: ['VITE_'] })
const __APP_INFO__ = {
  pkg: { dependencies, devDependencies, name, version },
  lastBuildTime: dayjs().format('YYYY-MM-DD HH:mm:ss'),
  importMeta: 'import.meta'
}
export default defineConfig({
  root: process.cwd(),
  server: {
    base: '/',
    host: '0.0.0.0',
    port: 3000,
    open: true,
    cors: true
  },
  resolve: {
    alias: {
      '@': resolve(__dirname, './src')
    }
  },
  html: {
    title: publicVars.VITE_APP_TITLE,
    template: './index.html'
  },
  source: {
    define: {
      __APP_INFO__: JSON.stringify(__APP_INFO__),
      // 启用生产环境构建下激活不匹配的详细警告
      __VUE_PROD_HYDRATION_MISMATCH_DETAILS__: 'false',
      ...publicVars
    },
    entry: {
      index: './src/main.ts'
    }
  },
  output: {
    distPath: {
      root: 'dist'
    },
    minify: true
  },
  plugins: createPlugins(),
  tools: {
    rspack: {
      plugins: [
        AutoImport({
          imports: ['vue', 'vue-router'],
          resolvers: [
            TDesignResolver({
              library: 'vue-next'
            })
          ],
          dts: 'src/autoImport.d.ts'
        }),
        Components({
          // allow auto load markdown components under `./src/components/`
          extensions: ['vue', 'md'],
          // allow auto import and register components used in markdown
          include: [/\.vue$/, /\.vue\?vue/, /\.md$/],
          resolvers: [
            TDesignResolver({
              library: 'vue-next'
            })
          ],
          dts: 'src/components.d.ts'
        })
      ]
    }
  }
})
